==> opencl-clhpp-2023.04.17-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/search/functions_6.js <==
var searchData=
[
  ['image_0',['Image',['../classcl_1_1_image.html#a644c4f0a68b5fbb716b0157f34d903b9',1,'cl::Image::Image(const cl_mem &amp;image, bool retainObject=false)'],['../classcl_1_1_image.html#ad9a2f4b6a5ccbb7056613946bc6ee0b7',1,'cl::Image::Image()']]],
  ['image1d_1',['Image1D',['../classcl_1_1_image1_d.html#a35633b9aa0bb3f2c23e48aa8fe3f7a9a',1,'cl::Image1D::Image1D(const Context &amp;context, cl_mem_flags flags, ImageFormat format, size_type width, void *host_ptr=nullptr, cl_int *err=nullptr)'],['../classcl_1_1_image1_d.html#a0d7c48026af3f726ce861716b6dbe817',1,'cl::Image1D::Image1D()'],['../classcl_1_1_image1_d.html#a7c8b730eba37624cb6d3af30f8a1c276',1,'cl::Image1D::Image1D(const cl_mem &amp;image1D, bool retainObject=false)']]],
  ['image1darray_2',['Image1DArray',['../classcl_1_1_image1_d_array.html#ae8738615a72593ca2ec82c20d736da03',1,'cl::Image1DArray']]],
  ['image1dbuffer_3',['Image1DBuffer',['../classcl_1_1_image1_d_buffer.html#a6b83eb1ccf0e1f88718a6f55c7340088',1,'cl::Image1DBuffer']]],
  ['image2d_4',['Image2D',['../classcl_1_1_image2_d.html#a2ca2508bd1029e23f9f0c673a27398c0',1,'cl::Image2D::Image2D(const Context &amp;context, cl_mem_flags flags, ImageFormat format, size_type width, size_type height, size_type row_pitch=0, void *host_ptr=nullptr, cl_int *err=nullptr)'],['../classcl_1_1_image2_d.html#abe1d541bfe4a39bc5bae819cd5c6ef0e',1,'cl::Image2D::Image2D(const Context &amp;context, ImageFormat format, const Buffer &amp;sourceBuffer, size_type width, size_type height, size_type row_pitch=0, cl_int *err=nullptr)'],['../classcl_1_1_image2_d.html#af6e0b8578a6e36d76854468ae9dee400',1,'cl::Image2D::Image2D(const Context &amp;context, cl_channel_order order, const Image &amp;sourceImage, cl_int *err=nullptr)'],['../classcl_1_1_image2_d.html#a6ef2c932d8846c4ad7205c5352df687a',1,'cl::Image2D::Image2D()'],['../classcl_1_1_image2_d.html#a2a8221a4c64c1aaf47468c4ef6c05a61',1,'cl::Image2D::Image2D(const cl_mem &amp;image2D, bool retainObject=false)']]],
  ['image2darray_5',['Image2DArray',['../classcl_1_1_image2_d_array.html#a8c16539dc725c60ef4ff4680f8353507',1,'cl::Image2DArray']]],
  ['image2dgl_6',['Image2DGL',['../classcl_1_1_image2_d_g_l.html#a621cec89650cdafd0098bba33c123e20',1,'cl::Image2DGL::Image2DGL(const Context &amp;context, cl_mem_flags flags, cl_GLenum target, cl_GLint miplevel, cl_GLuint texobj, cl_int *err=nullptr)'],['../classcl_1_1_image2_d_g_l.html#ada8671d0fd8072472bbb36c6786506d4',1,'cl::Image2DGL::Image2DGL(const cl_mem &amp;image, bool retainObject=false)'],['../classcl_1_1_image2_d_g_l.html#a0232c815761105f1c87e833a193b5bcc',1,'cl::Image2DGL::Image2DGL()']]],
  ['image3d_7',['Image3D',['../classcl_1_1_image3_d.html#acef8d3ef6b694fcec7934eb21776c1ea',1,'cl::Image3D::Image3D(const Context &amp;context, cl_mem_flags flags, ImageFormat format, size_type width, size_type height, size_type depth, size_type row_pitch=0, size_type slice_pitch=0, void *host_ptr=nullptr, cl_int *err=nullptr)'],['../classcl_1_1_image3_d.html#a9243ebeec223f4c6b9681e58b8844214',1,'cl::Image3D::Image3D()'],['../classcl_1_1_image3_d.html#a28f004720b4cc85a902d218e3dad680d',1,'cl::Image3D::Image3D(const cl_mem &amp;image3D, bool retainObject=false)']]],
  ['image3dgl_8',['Image3DGL',['../classcl_1_1_image3_d_g_l.html#a67727c118f3c7510a4382b4c72b955c2',1,'cl::Image3DGL::Image3DGL(const Context &amp;context, cl_mem_flags flags, cl_GLenum target, cl_GLint miplevel, cl_GLuint texobj, cl_int *err=nullptr)'],['../classcl_1_1_image3_d_g_l.html#a21a8fd551430095711413e831cd42ddd',1,'cl::Image3DGL::Image3DGL()'],['../classcl_1_1_image3_d_g_l.html#ae4379054235116bf4e7f1107914d0ce7',1,'cl::Image3DGL::Image3DGL(const cl_mem &amp;image, bool retainObject=false)']]],
  ['imageformat_9',['ImageFormat',['../structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14',1,'cl::ImageFormat::ImageFormat()'],['../structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba',1,'cl::ImageFormat::ImageFormat(cl_channel_order order, cl_channel_type type)'],['../structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b',1,'cl::ImageFormat::ImageFormat(const ImageFormat &amp;other)']]],
  ['imagegl_10',['ImageGL',['../classcl_1_1_image_g_l.html#afc06fdce130a034e8dca89ac910a93ab',1,'cl::ImageGL']]]
];

==> opencl-clhpp-2024.05.08-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/search/functions_6.js <==
var searchData=
[
  ['image_0',['Image',['../classcl_1_1_image.html#ad9a2f4b6a5ccbb7056613946bc6ee0b7',1,'cl::Image::Image()'],['../classcl_1_1_image.html#a644c4f0a68b5fbb716b0157f34d903b9',1,'cl::Image::Image(const cl_mem &amp;image, bool retainObject=false)']]],
  ['image1d_1',['Image1D',['../classcl_1_1_image1_d.html#a35633b9aa0bb3f2c23e48aa8fe3f7a9a',1,'cl::Image1D::Image1D(const Context &amp;context, cl_mem_flags flags, ImageFormat format, size_type width, void *host_ptr=nullptr, cl_int *err=nullptr)'],['../classcl_1_1_image1_d.html#a0d7c48026af3f726ce861716b6dbe817',1,'cl::Image1D::Image1D()'],['../classcl_1_1_image1_d.html#a7c8b730eba37624cb6d3af30f8a1c276',1,'cl::Image1D::Image1D(const cl_mem &amp;image1D, bool retainObject=false)']]],
  ['image1darray_2',['Image1DArray',['../classcl_1_1_image1_d_array.html#ae8738615a72593ca2ec82c20d736da03',1,'cl::Image1DArray']]],
  ['image1dbuffer_3',['Image1DBuffer',['../classcl_1_1_image1_d_buffer.html#a6b83eb1ccf0e1f88718a6f55c7340088',1,'cl::Image1DBuffer']]],
  ['image2d_4',['Image2D',['../classcl_1_1_image2_d.html#a2ca2508bd1029e23f9f0c673a27398c0',1,'cl::Image2D::Image2D(const Context &amp;context, cl_mem_flags flags, ImageFormat format, size_type width, size_type height, size_type row_pitch=0, void *host_ptr=nullptr, cl_int *err=nullptr)'],['../classcl_1_1_image2_d.html#abe1d541bfe4a39bc5bae819cd5c6ef0e',1,'cl::Image2D::Image2D(const Context &amp;context, ImageFormat format, const Buffer &amp;sourceBuffer, size_type width, size_type height, size_type row_pitch=0, cl_int *err=nullptr)'],['../classcl_1_1_image2_d.html#af6e0b8578a6e36d76854468ae9dee400',1,'cl::Image2D::Image2D(const Context &amp;context, cl_channel_order order, const Image &amp;sourceImage, cl_int *err=nullptr)'],['../classcl_1_1_image2_d.html#a6ef2c932d8846c4ad7205c5352df687a',1,'cl::Image2D::Image2D()'],['../classcl_1_1_image2_d.html#a2a8221a4c64c1aaf47468c4ef6c05a61',1,'cl::Image2D::Image2D(const cl_mem &amp;image2D, bool retainObject=false)']]],
  ['image2darray_5',['Image2DArray',['../classcl_1_1_image2_d_array.html#a8c16539dc725c60ef4ff4680f8353507',1,'cl::Image2DArray']]],
  ['image2dgl_6',['Image2DGL',['../classcl_1_1_image2_d_g_l.html#a621cec89650cdafd0098bba33c123e20',1,'cl::Image2DGL::Image2DGL(const Context &amp;context, cl_mem_flags flags, cl_GLenum target, cl_GLint miplevel, cl_GLuint texobj, cl_int *err=nullptr)'],['../classcl_1_1_image2_d_g_l.html#a0232c815761105f1c87e833a193b5bcc',1,'cl::Image2DGL::Image2DGL()'],['../classcl_1_1_image2_d_g_l.html#ada8671d0fd8072472bbb36c6786506d4',1,'cl::Image2DGL::Image2DGL(const cl_mem &amp;image, bool retainObject=false)']]],
  ['image3d_7',['Image3D',['../classcl_1_1_image3_d.html#acef8d3ef6b694fcec7934eb21776c1ea',1,'cl::Image3D::Image3D(const Context &amp;context, cl_mem_flags flags, ImageFormat format, size_type width, size_type height, size_type depth, size_type row_pitch=0, size_type slice_pitch=0, void *host_ptr=nullptr, cl_int *err=nullptr)'],['../classcl_1_1_image3_d.html#a9243ebeec223f4c6b9681e58b8844214',1,'cl::Image3D::Image3D()'],['../classcl_1_1_image3_d.html#a28f004720b4cc85a902d218e3dad680d',1,'cl::Image3D::Image3D(const cl_mem &amp;image3D, bool retainObject=false)']]],
  ['image3dgl_8',['Image3DGL',['../classcl_1_1_image3_d_g_l.html#a67727c118f3c7510a4382b4c72b955c2',1,'cl::Image3DGL::Image3DGL(const Context &amp;context, cl_mem_flags flags, cl_GLenum target, cl_GLint miplevel, cl_GLuint texobj, cl_int *err=nullptr)'],['../classcl_1_1_image3_d_g_l.html#a21a8fd551430095711413e831cd42ddd',1,'cl::Image3DGL::Image3DGL()'],['../classcl_1_1_image3_d_g_l.html#ae4379054235116bf4e7f1107914d0ce7',1,'cl::Image3DGL::Image3DGL(const cl_mem &amp;image, bool retainObject=false)']]],
  ['imageformat_9',['ImageFormat',['../structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14',1,'cl::ImageFormat::ImageFormat()'],['../structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba',1,'cl::ImageFormat::ImageFormat(cl_channel_order order, cl_channel_type type)'],['../structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b',1,'cl::ImageFormat::ImageFormat(const ImageFormat &amp;other)']]],
  ['imagegl_10',['ImageGL',['../classcl_1_1_image_g_l.html#afc06fdce130a034e8dca89ac910a93ab',1,'cl::ImageGL']]]
];
